import re

COUNTRY_CODE = re.compile(r"^[A-Z]{2}$")

SUBNATIONAL1_CODE = re.compile(r"^[A-Z]{2}-[A-Z0-9]{2,3}$")

SUBNATIONAL2_CODE = re.compile(r"^[A-Z]{2}-[A-Z0-9]{2,3}-[A-Z0-9]{2,3}$")

LOCATION_CODE = re.compile(r"^L\d+$")

REGION_TYPES = ["country", "subnational1", "subnational2"]


def is_national_code(value: str) -> bool:
    return COUNTRY_CODE.match(value) is not None


def is_subnational1_code(value: str) -> bool:
    return SUBNATIONAL1_CODE.match(value) is not None


def is_subnational2_code(value: str) -> bool:
    return SUBNATIONAL2_CODE.match(value) is not None


def is_location_code(value: str) -> bool:
    return LOCATION_CODE.match(value) is not None


def is_country_code(value: str) -> bool:
    return is_national_code(value)


def is_state_code(value: str) -> bool:
    return is_subnational1_code(value)


def is_county_code(value: str) -> bool:
    return is_subnational2_code(value) is not None


def is_region(value):
    return (
        is_national_code(value)
        or is_subnational1_code(value)
        or is_subnational2_code(value)
    )
